@@ -171,7 +171,7 @@ class DnnT(object):
 		Z = X.copy()
 		if type(self.inf_cov[k]) is list:
 			## for channels_last image data: shape should be (#samples, img_rows, img_cols, channel)
-			Z[:, self.inf_cov[k][0][:,None], self.inf_cov[k][1], 0] = 0.
+			Z[:, self.inf_cov[k][0][:,None], self.inf_cov[k][1], :] = 0.
 		else:
 			Z[:,self.inf_cov[k]]= 0.
 		return Z
@@ -191,7 +191,7 @@ class DnnT(object):
 		Z = X.copy()
 		if type(self.inf_cov[k]) is list:
 			## for channels_last image data: shape should be (#samples, img_rows, img_cols, channel)
-			Z[:,self.inf_cov[k][0][:,None], self.inf_cov[k][1], 0]= np.random.permutation(Z[:,self.inf_cov[k][0][:,None], self.inf_cov[k][1], 0])
+			Z[:,self.inf_cov[k][0][:,None], self.inf_cov[k][1], :]= np.random.permutation(Z[:,self.inf_cov[k][0][:,None], self.inf_cov[k][1], :])
 		else:
 			Z[:,self.inf_cov[k]]= np.random.permutation(Z[:,self.inf_cov[k]])
 		return Z
@@ -736,7 +736,7 @@ class DnnT(object):
 		self.p_values = P_value
 		return P_value
 
-	def visual(self, X, y):
+	def visual(self, X, y, plt_params={'cmap': 'RdBu', 'alpha':0.6}):
 		"""
 		Visualization for the inference results based on one illustrative example
 
@@ -747,6 +747,9 @@ class DnnT(object):
 
 		y : array-like
 		demo labels
+
+		plt_params: dict
+		dictory of parameters for the imshow see: https://matplotlib.org/3.3.3/api/_as_gen/matplotlib.pyplot.imshow.html
 		"""
 		if len(X.shape) == 2:
 			print('sorry, visual function only work for image data.')
@@ -765,7 +768,7 @@ class DnnT(object):
 					ax = fig.add_subplot(spec[row, col])
 					im1 = ax.imshow(X_demo[row], vmin=0, vmax=1)
 					ax.axis('off')
-					im2 = ax.imshow(X_mask_tmp, vmin=0, vmax=1, cmap='OrRd', alpha=0.6)
+					im2 = ax.imshow(X_mask_tmp, vmin=0, vmax=1, **plt_params)
 					ax.axis('off')
 					if row == 0:
 						ax.set_title('p_values: %.3f' %self.p_values[col])
